@@ -8,7 +8,7 @@
 
     copyright      : (C) 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
                      (C) 2001 The KDE-EDU team
-                      C) 2005 Peter Hedlund <peter@peterandlinda.com>
+                     (C) 2005 Peter Hedlund <peter.hedlund@kdemail.net>
 
     -----------------------------------------------------------------------
 
@@ -54,31 +54,16 @@
 #define KV_LEV7_GRADE      7
 #define KV_LEV7_TEXT       I18N_NOOP("Level 7")
 
-#include "langset.h"
-
 #include <time.h>
+#include <vector>
+using namespace std;
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <qpixmap.h>
-# include <qnamespace.h>
-
-#include "GrammerManager.h"
+#include "grammarmanager.h"
 #include "MultipleChoice.h"
 
-struct GradeCols {
-   bool   use;
-   QColor col0, col1, col2, col3, col4, col5, col6, col7;
-};
-
 typedef signed char grade_t;
 typedef unsigned short count_t;
 
-class kvoctrainDoc;
-class QPainter;
-
 /***************************************************************
   * This class contains one expression as original or in one
   * translations
@@ -94,7 +79,7 @@ class kvoctrainExpr
 
   kvoctrainExpr ();
 
-  kvoctrainExpr (QString &s, QString &separator, int lesson = 0);
+  kvoctrainExpr (QString &s, QString separator, int lesson = 0);
 
   /** Constructor for an expression in different languages
    *
